<?php

namespace Drupal\mailjet_event\Entity;

use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\mailjet_event\EventInterface;
use Drupal\Core\Entity\EntityChangedTrait;
use Drupal\user\EntityOwnerTrait;

/**
 * Defines the Event entity.
 *
 * @ingroup mailjet_event
 *
 * @ContentEntityType(
 *   id = "mailjet_event",
 *   label = @Translation("Mailjet event"),
 *   list_cache_contexts = { "user" },
 *   base_table = "mailjet_event",
 *   admin_permission = TRUE,
 *   entity_keys = {
 *     "id" = "event_id",
 *     "uuid" = "uuid",
 *     "owner" = "uid"
 *   },
 * )
 */
class Event extends ContentEntityBase implements EventInterface {

  use EntityOwnerTrait;
  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   */
  public function getCreatedTime() {
    return $this->get('created')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function getChangedTime() {
    return $this->get('changed')->value;
  }

  /**
   * Define the field properties here.
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = static::ownerBaseFieldDefinitions($entity_type);

    // Standard field, used as unique if primary index.
    $fields['event_id'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('ID'))
      ->setDescription(t('The ID of the Event.'))
      ->setReadOnly(TRUE);

    // Standard field, unique outside of the scope of the current project.
    $fields['uuid'] = BaseFieldDefinition::create('uuid')
      ->setLabel(t('UUID'))
      ->setDescription(t('The UUID of the Event.'))
      ->setReadOnly(TRUE);

    $fields['event_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Event type - String'))
      ->setDescription(t('Event type - String'))
      ->setReadOnly(TRUE);

    $fields['event_field'] = BaseFieldDefinition::create('map')
      ->setLabel(t('Event'))
      ->setDescription(t('Event description'))
      ->setRevisionable(TRUE)
      ->setDefaultValue([]);

    $fields['langcode'] = BaseFieldDefinition::create('language')
      ->setLabel(t('Language code'))
      ->setDescription(t('The language code of  Campaign.'));

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setDescription(t('The time that the  Campaign entity was created.'));

    $fields['changed'] = BaseFieldDefinition::create('changed')
      ->setLabel(t('Changed'))
      ->setDescription(t('The time that the  Campaign entity was last edited.'));

    return $fields;
  }

}
