<?php

namespace Drupal\mailjet_subscription\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Subscription form entity.
 *
 * @ingroup mailjet_subscription
 *
 * @ConfigEntityType(
 *   id = "mailjet_subscription_form",
 *   label = @Translation("Subscription Form"),
 *   admin_permission = "administer subscriptions",
 *   handlers = {
 *     "access" = "Drupal\mailjet_subscription\SubscriptionFormController",
 *     "list_builder" = "Drupal\mailjet_subscription\Controller\SubscriptionFormBuilder",
 *     "form" = {
 *       "add" = "Drupal\mailjet_subscription\Form\SubscriptionFormAddForm",
 *       "edit" = "Drupal\mailjet_subscription\Form\SubscriptionFormEditForm",
 *       "delete" = "Drupal\mailjet_subscription\Form\SubscriptionFormDeleteForm"
 *     }
 *   },
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label"
 *   },
 *   links = {
 *     "edit-form" = "/examples/mailjet_subscription/manage/{mailjet_subscription_form}",
 *     "delete-form" = "/examples/mailjet_subscription/manage/{mailjet_subscription_form}/delete"
 *   },
 *   config_export = {
 *      "id" = "id",
 *      "name" = "name",
 *      "uuid" = "uuid",
 *      "description" = "description",
 *      "sumbit_label" = "sumbit_label",
 *      "destination_page" = "destination_page",
 *      "error_token" = "error_token",
 *      "confirmation_email_text" = "confirmation_email_text",
 *      "email_text_button" = "email_text_button",
 *      "email_text_description" = "email_text_description",
 *      "email_text_thank_you" = "email_text_thank_you",
 *      "email_owner" = "email_owner",
 *      "contact_exist" = "contact_exist",
 *      "lists" = "lists",
 *      "fields_mailjet" = "fields_mailjet",
 *      "css_field" = "css_field",
 *      "js_field" = "js_field",
 *      "email_footer_text" = "email_footer_text",
 *      "error_data_types" = "error_data_types",
 *      "confirmation_message" = "confirmation_message",
 *      "subscribe_error" = "subscribe_error",
 *      "success_message_subsribe" = "success_message_subsribe",
 *      "created_date" = "created_date",
 *      "changed_date" = "changed_date",
 *      "email_label" = "email_label",
 *      "labels_fields" = "labels_fields",
 *      "sort_fields" = "sort_fields"
 *   }
 * )
 */
class SubscriptionForm extends ConfigEntityBase {

  /**
   * The Signup ID.
   *
   * @var int
   */
  public $id;

  /**
   * The Signup Form Machine Name.
   *
   * @var string
   */
  public $name;

  /**
   * The Signup Form Description.
   *
   * @var string
   */
  public $description;

  /**
   * The Signup Form Label of Sumbit button.
   *
   * @var string
   */
  public $sumbit_label;

  /**
   * The Signup Form Destination Page.
   *
   * @var string
   */
  public $destination_page;

  /**
   * The Signup Form Confirmation Message.
   *
   * @var string
   */
  public $confirmation_message;

  /**
   * The Signup Form Error token.
   *
   * @var string
   */
  public $error_token;


  /**
   * The Signup Form Confirmation Rmail Text.
   *
   * @var string
   */
  public $confirmation_email_text;


  /**
   * The Signup Form Email Text Button.
   *
   * @var string
   */
  public $email_text_button;


  /**
   * The Signup Form Email Text Description.
   *
   * @var string
   */
  public $email_text_description;

  /**
   * The Signup Form Email Thank You Message.
   *
   * @var string
   */
  public $email_text_thank_you;

  /**
   * The Signup Form Email Owner.
   *
   * @var string
   */
  public $email_owner;

  /**
   * The Signup Form Subscribe Error.
   *
   * @var string
   */
  public $subscribe_error;

  /**
   * The Signup Form Contact Exist Message.
   *
   * @var string
   */
  public $contact_exist;

  /**
   * The Signup Form Success Message Subscribe.
   *
   * @var string
   */
  public $success_message_subsribe;

  /**
   * The Signup Form lists.
   *
   * @var array
   */
  public $lists;

  /**
   * The Signup Form Conctact propeties.
   *
   * @var array
   */
  public $fields_mailjet;

  /**
   * The Signup Form CSS Field.
   *
   * @var array
   */
  public $css_field;

  /**
   * The Signup Form Js Field.
   *
   * @var string
   */
  public $js_field;

  /**
   * The Signup Form Email Footer Text.
   *
   * @var string
   */
  public $email_footer_text;

  /**
   * The Signup Form Error Data Type Message.
   *
   * @var string
   */
  public $error_data_types;

  /**
   * The Signup Form Sort fields - String.
   *
   * @var string
   */
  public $sort_fields;

  /**
   * {@inheritdoc}
   */
  public function save() {
    $entity = parent::save();
    // Invalidate the block cache to update block derivatives.
    if (\Drupal::moduleHandler()->moduleExists('block')) {
      \Drupal::service('plugin.manager.block')->clearCachedDefinitions();
    }
    return $entity;
  }

  /**
   * {@inheritdoc}
   */
  public function delete() {
    parent::delete();
    // Invalidate the block cache to update block derivatives.
    if (\Drupal::moduleHandler()->moduleExists('block')) {
      \Drupal::service('plugin.manager.block')->clearCachedDefinitions();
    }
  }

}
