<?php

namespace Drupal\mailjet_subscription\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Form for subscription labels.
 */
class MailjetSubscriptionLabelsForm extends ConfigFormBase {

  /**
   * Entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * MailjetSubscriptionLabelsForm constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Configuration object factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   Entity type manager service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    EntityTypeManagerInterface $entityTypeManager
  ) {
    parent::__construct($config_factory);
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'mailjet_labels.adminsettings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'mailjet_labels_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, string $entityId = NULL) {

    $signup_form = $this->entityTypeManager
      ->getStorage('mailjet_subscription_form')
      ->load($entityId);
    if (!$signup_form) {
      throw new NotFoundHttpException();
    }

    $form['entity_id'] = [
      '#type' => 'hidden',
      '#default_value' => $entityId,
    ];

    $form['subscribe_field_email'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Email'),
      '#default_value' => $signup_form->email_label,
      '#required' => TRUE,
    ];

    $fields = explode(',', $signup_form->fields_mailjet);
    $labels_fields = explode(',', $signup_form->labels_fields);
    $counter = 0;

    if (!(empty($fields[0]))) {
      foreach ($fields as $field) {
        $form['singup-' . $field] = [
          '#type' => 'textfield',
          '#title' => $this->t("Label of 'machine name' field: %field", ['%field' => $field]),
          '#description' => '',
          '#required' => TRUE,
          '#default_value' => $labels_fields[$counter] ?? '',
        ];

        $counter++;
      }
    }

    $form['actions']['#type'] = 'actions';

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
      '#button_type' => 'primary',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $entity = $this->entityTypeManager
      ->getStorage('mailjet_subscription_form')
      ->load($form_state->getValue('entity_id'));

    $entity->set('email_label', $form_state->getValue('subscribe_field_email'));

    $fields = explode(',', $entity->fields_mailjet);
    $fields_label = [];

    if (!(empty($fields[0]))) {
      foreach ($fields as $field) {
        $label = !empty($form_state->getValue('singup-' . $field)) ? $form_state->getValue('singup-' . $field) : '';
        $fields_label[] = $label;

      }

      $entity->set('labels_fields', implode(',', $fields_label));
    }

    $status = $entity->save();

    if ($status == SAVED_UPDATED) {
      $this->messenger()->addStatus($this->t('Subscription Form Labels have been updated.'));
    }
    else {
      $this->messenger()->addStatus($this->t("Subscription Form Labels haven't been updated."));
    }

  }

}
