<?php

namespace Drupal\mailjet_subscription\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Provides the add form for our Subscription Form.
 *
 * @ingroup mailjet_subscription
 */
class SubscriptionFormEditForm extends SubscriptionFormFormBase {

  /**
   * {@inheritDoc}
   */
  protected function actions(array $form, FormStateInterface $form_state) {
    $actions = parent::actions($form, $form_state);
    $actions['submit']['#value'] = $this->t('Save');
    return $actions;
  }

  /**
   * {@inheritDoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $form['actions']['edit_labels'] = [
      '#type' => 'submit',
      '#weight' => 30,
      '#limit_validation_errors' => [],
      '#submit' => [
        '::redirectToLabelForm',
      ],
      '#value' => $this->t('Edit Labels'),
    ];
    $form['#attached']['library'][] = 'mailjet_subscription/sort_properties';

    return $form;
  }

  /**
   * Edit labels submit function.
   */
  public function redirectToLabelForm(&$form, FormStateInterface $form_state) {
    $entity_id = $form['id']['#default_value'];

    $redirectUrl = Url::fromRoute('mailjet_subscription.labels_form_settings', [
      'entityId' => $entity_id,
    ]);
    $response = new RedirectResponse($redirectUrl->toString());
    $response->send();
  }

}
