<?php

namespace Drupal\mailjet_subscription\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\DependencyInjection\ClassResolverInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\mailjet_subscription\Form\SubscriptionSignupPageForm;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'Subscribe' block.
 *
 * @Block(
 *   id = "mailjet_signup_subscribe_block",
 *   admin_label = @Translation("Subscribe Block"),
 *   category = @Translation("Mailjet Signup"),
 *   module = "mailjet_subscription",
 *   deriver =
 *   "Drupal\mailjet_subscription\Plugin\Derivative\SubscriptionDerivativeBlock"
 * )
 */
class SubscriptionFormBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * Entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Form builder service.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * Class resolver service.
   *
   * @var \Drupal\Core\DependencyInjection\ClassResolverInterface
   */
  private $classResolver;

  /**
   * Constructs a SubscriptionFormBlock object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager service.
   * @param \Drupal\Core\Form\FormBuilderInterface $formBuilder
   *   The form builder service.
   * @param \Drupal\Core\DependencyInjection\ClassResolverInterface $classResolver
   *   The class resolver service.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    EntityTypeManagerInterface $entityTypeManager,
    FormBuilderInterface $formBuilder,
    ClassResolverInterface $classResolver
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->entityTypeManager = $entityTypeManager;
    $this->formBuilder = $formBuilder;
    $this->classResolver = $classResolver;
  }

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager'),
      $container->get('form_builder'),
      $container->get('class_resolver')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $signup_id = $this->getDerivativeId();
    $content = NULL;

    /** @var \Drupal\mailjet_subscription\Entity\SubscriptionForm $signup */
    $signup = $this->entityTypeManager
      ->getStorage('mailjet_subscription_form')
      ->load($signup_id);

    if ($signup !== NULL) {
      $form = $this->classResolver->getInstanceFromDefinition(SubscriptionSignupPageForm::class);

      $form_id = 'mailjet_signup_subscribe_block_' . $signup->id() . '_form';
      $form->setFormId($form_id);
      $form->setSignupId($signup->id());

      $content = $this->formBuilder->getForm($form);
    }

    return $content;
  }

}
