<?php

namespace Drupal\mailjet\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Routing\Access\AccessInterface;

/**
 * Checks access for displaying configuration Mailjet pages.
 */
class MailjetConfigurationAccessCheck implements AccessInterface {

  /**
   * Access check for Mailjet module configuration.
   *
   * Ensures a Mailjet API keys has been provided.
   */
  public function access(RouteMatchInterface $route_match, AccountInterface $account) {
    // Check for permission.
    if (!$account->hasPermission('administer mailjet configuration')) {
      return AccessResult::forbidden();
    }

    $config_mailjet = \Drupal::config('mailjet.settings');
    if (empty($config_mailjet->get('mailjet_active'))
      || empty($config_mailjet->get('mailjet_username'))
      || empty($config_mailjet->get('mailjet_password'))) {

      if ($route_match->getRouteName() !== 'mailjet_api.admin_settings_form') {
        // @todo Replace $base_url usage with Url::fromUri() build.
        global $base_url;
        \Drupal::messenger()->addWarning(t('You need to add your MailJet API details before you can continue! Enter your Mailjet Api keys <a href="' . $base_url . '/admin/config/system/mailjet/api">here.</a>'));
      }
      return AccessResult::forbidden();
    }

    return AccessResult::allowed();
  }

}
